1.14.9 — Rucio 1.2 documentation

# 1.14.9

## General

### Features

- Extensions: Functionality to include TTC for a rule in rucio rule-info #530

### Enhancements

- Core & Internals: CMS Site name rules need to be in RSE attributes as well. #554
- Core & Internals: Do not require space tokens for SRM #574
- Documentation: add Client API description to the documentation #557
- Documentation: Contributor guide should only be one line in the main documentation TOC #560
- Documentation: Broken autogeneration of the API documentation #596
- Documentation: add requirements.readthedocs.txt #597
- Documentation: Update and move AUTHORS file to AUTHORS.rst and 2018 #619
- Documentation: Modify sphinx template to get the default in on rtd #622
- Documentation: Add autogenerated documentation for bin/rucio command line tool #626
- Probes & Alarms: Flag to enable/disable the check of busy links in FTS probe #587
- Transfers: S3 third party copy scheme mismatchs #634

### Bugs

- Core & Internals: Fix naming convention validation #612
- Core & Internals: rest: add missing variable to global instantion #707
- Probes & Alarms: Handling of non-expected value in json in check_rses_distance #604

## Clients

### Enhancements

- Clients: client: Allow rucio-admin to manage protocols #327
- Clients: clients: automatically select lan/wan replica based on location #450
- Clients: clients: Add CLI for manipulating distance information #469
- Clients: Add creation date as output to rucio list-rules –account #548
- Core & Internals: Handle Apache failures gracefully #576

## WebUI

### Enhancements

- WebUI: WebUI: Metalink download for datasets #343 #343

### Bugs

- WebUI: Fix footer in account_usage table #563